@@ -11,10 +11,10 @@ def get_statement_import_as(statement):
     :returns: a mapping of names {<realname>: <alias>} of modules imported
     :rtype: collections.OrderedDict
     """
-    if not any([isinstance(statement, ast.Import),
-                isinstance(statement, ast.ImportFrom)]):
-        raise ValueError("Value given is not an ast import or "
-                         "import from statement")
+    if not any(
+        [isinstance(statement, ast.Import), isinstance(statement, ast.ImportFrom)]
+    ):
+        raise ValueError("Value given is not an ast import or " "import from statement")
     result = collections.OrderedDict()
     for name in statement.names:
         if name.asname is not None:
