@@ -36,9 +36,7 @@ class ByStatusLink(ResultEvents):
         pass
 
     def end_test(self, result, state):
-        link = state.get('logdir')
-        where = os.path.join(os.path.dirname(link),
-                             'by-status',
-                             state.get('status'))
+        link = state.get("logdir")
+        where = os.path.join(os.path.dirname(link), "by-status", state.get("status"))
         os.makedirs(where, exist_ok=True)
         os.symlink(link, os.path.join(where, os.path.basename(link)))
