@@ -4,7 +4,7 @@ import sys
 
 from avocado.core.job import Job
 
-config = {'resolver.references': ['examples/tests/failtest.py:FailTest.test']}
+config = {"resolver.references": ["examples/tests/failtest.py:FailTest.test"]}
 
 with Job(config) as j:
     sys.exit(j.run())
