@@ -11,10 +11,9 @@ from avocado.core.suite import TestSuite
 # be used for suite.name. Also resolver.references will be ignored (Avocado will not
 # creating tests suites for you).
 
-suite1 = TestSuite(name='suite1', tests=[Runnable("noop", "noop")])
-suite2 = TestSuite(name='suite2', tests=[Runnable("noop", "noop")])
-suite3 = TestSuite(name='suite3', enabled=False,
-                   tests=[Runnable("noop", "noop")])
+suite1 = TestSuite(name="suite1", tests=[Runnable("noop", "noop")])
+suite2 = TestSuite(name="suite2", tests=[Runnable("noop", "noop")])
+suite3 = TestSuite(name="suite3", enabled=False, tests=[Runnable("noop", "noop")])
 
 with Job(test_suites=[suite1, suite2, suite3]) as j:
     sys.exit(j.run())
