@@ -5,8 +5,10 @@ import sys
 from avocado.core.job import Job
 from avocado.core.suite import TestSuite
 
-config = {'resolver.references': ['examples/tests/passtest.py:PassTest.test'],
-          'job.run.result.html.enabled': True}
+config = {
+    "resolver.references": ["examples/tests/passtest.py:PassTest.test"],
+    "job.run.result.html.enabled": True,
+}
 
 suite = TestSuite.from_config(config)
 with Job(config, [suite]) as j:
