@@ -18,21 +18,19 @@ class PrintVariableTest(Test):
     :param source: name of the source file located in a data directory
     """
 
-    __binary = None    # filename of the compiled program
+    __binary = None  # filename of the compiled program
 
     def setUp(self):
         """
         Build 'print_variable'.
         """
-        source = self.params.get('source', default='print_variable.c')
+        source = self.params.get("source", default="print_variable.c")
         c_file = self.get_data(source)
         if c_file is None:
-            self.cancel(f'Test is missing data file {source}')
+            self.cancel(f"Test is missing data file {source}")
         shutil.copy(c_file, self.workdir)
-        self.__binary = source.rsplit('.', 1)[0]
-        build.make(self.workdir,
-                   env={'CFLAGS': '-g -O0'},
-                   extra_args=self.__binary)
+        self.__binary = source.rsplit(".", 1)[0]
+        build.make(self.workdir, env={"CFLAGS": "-g -O0"}, extra_args=self.__binary)
 
     def test(self):
         """
