@@ -15,6 +15,6 @@ class AsyncSleepTest(Test):
         """
         Sleep for length seconds.
         """
-        sleep_length = float(self.params.get('sleep_length', default=1))
+        sleep_length = float(self.params.get("sleep_length", default=1))
         self.log.debug("Sleeping for %.2f seconds", sleep_length)
         await asyncio.sleep(sleep_length)
