@@ -17,7 +17,6 @@ class TimeoutTest(Test):
         """
         This should throw a TestTimeoutError.
         """
-        sleep_time = self.params.get('sleep_time', default=5)
-        self.log.info('Sleeping for %.2f seconds (2 more than the timeout)',
-                      sleep_time)
+        sleep_time = self.params.get("sleep_time", default=5)
+        self.log.info("Sleeping for %.2f seconds (2 more than the timeout)", sleep_time)
         time.sleep(sleep_time)
